var indexSectionsWithContent =
{
  0: "0abcdefghilmnprsvw",
  1: "adfiw",
  2: "w",
  3: "cdghilmprsv",
  4: "abdilmnprv",
  5: "mw"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "functions",
  4: "variables",
  5: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Functions",
  4: "Variables",
  5: "Pages"
};

